@@ -4,6 +4,7 @@
 ----
 
 """
+import time
 
 try:
     import re
@@ -32,6 +33,8 @@ try:
 except:
     logs.安全退出("Fishsys依赖包导入出错，程序无法运行")
 
+
+from Fishconsole import houtai
 # 导入强制更新系统所需要的内容
 
 
@@ -115,6 +118,7 @@ def Fishconsole_Update():
     global 开始时间, 结束时间, day, month,递归更新次数
 
 
+
     递归更新次数 = 递归更新次数 + 1
     if 递归更新次数 > 4:
         print(logs.日志("强制更新系统更新时出现故障，强制更新退出，这个问题应该是本地版本号和云控版本号和包管理器的版本号对不上所造成的", "红色"))
@@ -307,6 +311,7 @@ def Fishconsole_Update():
                         os.system("python.exe -m pip install --upgrade pip -i https://pypi.douban.com/simple")
                         os.system(f'pip install --upgrade Fishconsole')
                         main(['install', '--upgrade', 'Fishconsole'])
+
                     except:
                         logs.日志("强制更新系统》pip命令组出现未知错误，程序强制退出", "红色")
 
@@ -1306,3 +1311,45 @@ def 任务平均分配(任务数量, 数据源: list):
         return 完成列表
     else:
         logs.安全退出("任务平均分配》数据源类型检测》请指定正确的类型")
+
+
+# 规定调用次数
+# import time
+# from functools import wraps
+# def 装饰器(参数):
+#   "缓存表示函数“结果”，它是不可变的，参数固定 "
+#   print (f"缓存初始化在{参数.__name__}")
+#   缓存 = {}
+#   @wraps(参数)
+#   def 装饰器函数(*args,**kwargs):
+#     # 函数的名称作为key
+#     钥匙 = 参数.__name__
+#     结果 = None
+#     #判断是否存在缓存
+#     if 钥匙 in 缓存.keys():
+#       (结果, 更新时间) = 缓存[钥匙]
+#       #过期时间固定为10秒
+#       if time.time() -更新时间 < 10:
+#         print ("时间未到10s在", 钥匙)
+#         结果 = 更新时间
+#       else :
+#         print ("缓存已过期，支持调用")
+#         结果 = None
+#     else:
+#       print ("没有缓存在", 钥匙)
+#     #如果过期，或则没有缓存调用方法
+#     if 结果 is None:
+#       结果 = 参数(*args, **kwargs)
+#       缓存[钥匙] = (结果, time.time())
+#     return 结果
+#   return 装饰器函数
+# @装饰器
+# def 参数(x):
+#   print('函数已调用')
+
+
+
+
+
+
+
