@@ -84,15 +84,16 @@ def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc",变量名=No
     就是存数据，方便程序在下一次运行的时候调用
 
 
-    模式:1是存储，2是读取
+    语法就是\n\n"
 
-    数据:你要存的数据
 
-    变量名: 获取字典中的变量名，默认没有就会返回一个完整的字典
+    files.缓存(1,数据={})【这个是覆盖写入，原来的所有东西会消失】\n\n"
 
-    文件名:指定的文件名（默认为Fishconsole.fcc）
 
-    :return:  文件或者dict类型的值，如果没有缓存文件就返回False的布尔值
+    files.缓存(2,变量名='缓存名')【这个是读取，如果你指定了变量名，我们就会返回这个值对应的内容,反之返回全部（返回全部是针对大规模读写性能太差的问题的解决方案）】\n\n"
+
+
+    files.缓存(3,数据)【这个是插入，修改或增加部分缓存内容】"
     """
     模式 = str(模式)
     if 模式 == "1":
